from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SysInfoModel")


@attr.s(auto_attribs=True)
class SysInfoModel:
    """For the most part, copied from
    https://github.com/FNNDSC/pfcon/blob/87f5da953be7c2cc80542bef0e67727dda1b4958/pfcon/pfcon.py#L601-611

    Provides information about the environment in which the service
    is currently running.

        Attributes:
            version (str):
            memory (List[Any]): Actually a NamedTuple but I'm not typing it out
            loadavg (List[Any]): Average system load over last 1, 5, and 15 minutes
            cpu_percent (float):
            system (Union[Unset, str]):  Default: 'Linux'.
            machine (Union[Unset, str]):  Default: 'x86_64'.
            uname (Union[Unset, List[str]]): Uname output, converted from object to list
            platform (Union[Unset, str]):  Default: 'Linux-6.2.2-zen1-1-zen-x86_64-with-glibc2.2.5'.
            cpucount (Union[Unset, int]):  Default: 16.
            hostname (Union[Unset, str]):  Default: '004ba48a5ffc'.
            inet (Union[Unset, str]):  Default: '172.17.0.2'.
    """

    version: str
    memory: List[Any]
    loadavg: List[Any]
    cpu_percent: float
    system: Union[Unset, str] = "Linux"
    machine: Union[Unset, str] = "x86_64"
    uname: Union[Unset, List[str]] = UNSET
    platform: Union[Unset, str] = "Linux-6.2.2-zen1-1-zen-x86_64-with-glibc2.2.5"
    cpucount: Union[Unset, int] = 16
    hostname: Union[Unset, str] = "004ba48a5ffc"
    inet: Union[Unset, str] = "172.17.0.2"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        version = self.version
        memory = self.memory

        loadavg = self.loadavg

        cpu_percent = self.cpu_percent
        system = self.system
        machine = self.machine
        uname: Union[Unset, List[str]] = UNSET
        if not isinstance(self.uname, Unset):
            uname = self.uname

        platform = self.platform
        cpucount = self.cpucount
        hostname = self.hostname
        inet = self.inet

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "version": version,
                "memory": memory,
                "loadavg": loadavg,
                "cpu_percent": cpu_percent,
            }
        )
        if system is not UNSET:
            field_dict["system"] = system
        if machine is not UNSET:
            field_dict["machine"] = machine
        if uname is not UNSET:
            field_dict["uname"] = uname
        if platform is not UNSET:
            field_dict["platform"] = platform
        if cpucount is not UNSET:
            field_dict["cpucount"] = cpucount
        if hostname is not UNSET:
            field_dict["hostname"] = hostname
        if inet is not UNSET:
            field_dict["inet"] = inet

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        version = d.pop("version")

        memory = cast(List[Any], d.pop("memory"))

        loadavg = cast(List[Any], d.pop("loadavg"))

        cpu_percent = d.pop("cpu_percent")

        system = d.pop("system", UNSET)

        machine = d.pop("machine", UNSET)

        uname = cast(List[str], d.pop("uname", UNSET))

        platform = d.pop("platform", UNSET)

        cpucount = d.pop("cpucount", UNSET)

        hostname = d.pop("hostname", UNSET)

        inet = d.pop("inet", UNSET)

        sys_info_model = cls(
            version=version,
            memory=memory,
            loadavg=loadavg,
            cpu_percent=cpu_percent,
            system=system,
            machine=machine,
            uname=uname,
            platform=platform,
            cpucount=cpucount,
            hostname=hostname,
            inet=inet,
        )

        sys_info_model.additional_properties = d
        return sys_info_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LogCore")


@attr.s(auto_attribs=True)
class LogCore:
    """Model for the core log info saved to DB

    Attributes:
        url (Union[Unset, str]):  Default: 'http://localhost:2223'.
        username (Union[Unset, str]):  Default: 'any'.
        password (Union[Unset, str]):  Default: 'any'.
        db_dir (Union[Unset, str]):  Default: '/home/dicom'.
        telemetry_dir (Union[Unset, str]):  Default: 'telemetry'.
        description (Union[Unset, str]):  Default: 'Add a description!'.
    """

    url: Union[Unset, str] = "http://localhost:2223"
    username: Union[Unset, str] = "any"
    password: Union[Unset, str] = "any"
    db_dir: Union[Unset, str] = "/home/dicom"
    telemetry_dir: Union[Unset, str] = "telemetry"
    description: Union[Unset, str] = "Add a description!"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        url = self.url
        username = self.username
        password = self.password
        db_dir = self.db_dir
        telemetry_dir = self.telemetry_dir
        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if url is not UNSET:
            field_dict["url"] = url
        if username is not UNSET:
            field_dict["username"] = username
        if password is not UNSET:
            field_dict["password"] = password
        if db_dir is not UNSET:
            field_dict["dbDir"] = db_dir
        if telemetry_dir is not UNSET:
            field_dict["telemetryDir"] = telemetry_dir
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        url = d.pop("url", UNSET)

        username = d.pop("username", UNSET)

        password = d.pop("password", UNSET)

        db_dir = d.pop("dbDir", UNSET)

        telemetry_dir = d.pop("telemetryDir", UNSET)

        description = d.pop("description", UNSET)

        log_core = cls(
            url=url,
            username=username,
            password=password,
            db_dir=db_dir,
            telemetry_dir=telemetry_dir,
            description=description,
        )

        log_core.additional_properties = d
        return log_core

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.log_core import LogCore
    from ..models.time import Time


T = TypeVar("T", bound="LogInit")


@attr.s(auto_attribs=True)
class LogInit:
    """A full model that is returned from a query call

    Attributes:
        info (LogCore): Model for the core log info saved to DB
        time_created (Time): A simple model that has a time string field
        time_modified (Time): A simple model that has a time string field
        message (str):
    """

    info: "LogCore"
    time_created: "Time"
    time_modified: "Time"
    message: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        info = self.info.to_dict()

        time_created = self.time_created.to_dict()

        time_modified = self.time_modified.to_dict()

        message = self.message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "info": info,
                "time_created": time_created,
                "time_modified": time_modified,
                "message": message,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.log_core import LogCore
        from ..models.time import Time

        d = src_dict.copy()
        info = LogCore.from_dict(d.pop("info"))

        time_created = Time.from_dict(d.pop("time_created"))

        time_modified = Time.from_dict(d.pop("time_modified"))

        message = d.pop("message")

        log_init = cls(
            info=info,
            time_created=time_created,
            time_modified=time_modified,
            message=message,
        )

        log_init.additional_properties = d
        return log_init

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.echo_model import EchoModel
    from ..models.sys_info_model import SysInfoModel


T = TypeVar("T", bound="HelloModel")


@attr.s(auto_attribs=True)
class HelloModel:
    """The model describing the relevant "hello" data

    Attributes:
        name (Union[Unset, str]):  Default: 'pfdcm_hello'.
        version (Union[Unset, str]):  Default: '1.0.0'.
        sysinfo (Union[Unset, SysInfoModel]): For the most part, copied from
            https://github.com/FNNDSC/pfcon/blob/87f5da953be7c2cc80542bef0e67727dda1b4958/pfcon/pfcon.py#L601-611

            Provides information about the environment in which the service
            is currently running.
        echo_back (Union[Unset, EchoModel]): Simply echo back whatever is POSTed to this API endpoing
    """

    name: Union[Unset, str] = "pfdcm_hello"
    version: Union[Unset, str] = "1.0.0"
    sysinfo: Union[Unset, "SysInfoModel"] = UNSET
    echo_back: Union[Unset, "EchoModel"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        version = self.version
        sysinfo: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sysinfo, Unset):
            sysinfo = self.sysinfo.to_dict()

        echo_back: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.echo_back, Unset):
            echo_back = self.echo_back.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if version is not UNSET:
            field_dict["version"] = version
        if sysinfo is not UNSET:
            field_dict["sysinfo"] = sysinfo
        if echo_back is not UNSET:
            field_dict["echoBack"] = echo_back

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.echo_model import EchoModel
        from ..models.sys_info_model import SysInfoModel

        d = src_dict.copy()
        name = d.pop("name", UNSET)

        version = d.pop("version", UNSET)

        _sysinfo = d.pop("sysinfo", UNSET)
        sysinfo: Union[Unset, SysInfoModel]
        if isinstance(_sysinfo, Unset):
            sysinfo = UNSET
        else:
            sysinfo = SysInfoModel.from_dict(_sysinfo)

        _echo_back = d.pop("echoBack", UNSET)
        echo_back: Union[Unset, EchoModel]
        if isinstance(_echo_back, Unset):
            echo_back = UNSET
        else:
            echo_back = EchoModel.from_dict(_echo_back)

        hello_model = cls(
            name=name,
            version=version,
            sysinfo=sysinfo,
            echo_back=echo_back,
        )

        hello_model.additional_properties = d
        return hello_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import Client
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    log_object: str,
    log_collection: str,
    *,
    client: Client,
    style: Union[Unset, None, str] = "plain",
    padding: Union[Unset, None, bool] = False,
    fields: Union[Unset, None, str] = "",
) -> Dict[str, Any]:
    url = "{}/api/v1/log/{logObject}/{logCollection}/csv".format(
        client.base_url, logObject=log_object, logCollection=log_collection
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["style"] = style

    params["padding"] = padding

    params["fields"] = fields

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[HTTPValidationError, str]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = cast(str, response.json())
        return response_200
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[HTTPValidationError, str]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    log_object: str,
    log_collection: str,
    *,
    client: Client,
    style: Union[Unset, None, str] = "plain",
    padding: Union[Unset, None, bool] = False,
    fields: Union[Unset, None, str] = "",
) -> Response[Union[HTTPValidationError, str]]:
    """
        GET all the events comprising this log object collection as
        a CSV formatted string


     Description
    -----------
    GET all the events in the collection `logCollection` of the object
    `logObject` as a CSV formatted string.

    By passing a URL query as `style=fancy` a _fancy_ CSV payload is
    returned. Passing a comma-separated string of `fields=<strlist>`
    will only return the `strlist` tokens in the CSV.

    Args:
        log_object (str):
        log_collection (str):
        style (Union[Unset, None, str]):  Default: 'plain'.
        padding (Union[Unset, None, bool]):
        fields (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, str]]
    """

    kwargs = _get_kwargs(
        log_object=log_object,
        log_collection=log_collection,
        client=client,
        style=style,
        padding=padding,
        fields=fields,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    log_object: str,
    log_collection: str,
    *,
    client: Client,
    style: Union[Unset, None, str] = "plain",
    padding: Union[Unset, None, bool] = False,
    fields: Union[Unset, None, str] = "",
) -> Optional[Union[HTTPValidationError, str]]:
    """
        GET all the events comprising this log object collection as
        a CSV formatted string


     Description
    -----------
    GET all the events in the collection `logCollection` of the object
    `logObject` as a CSV formatted string.

    By passing a URL query as `style=fancy` a _fancy_ CSV payload is
    returned. Passing a comma-separated string of `fields=<strlist>`
    will only return the `strlist` tokens in the CSV.

    Args:
        log_object (str):
        log_collection (str):
        style (Union[Unset, None, str]):  Default: 'plain'.
        padding (Union[Unset, None, bool]):
        fields (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, str]]
    """

    return sync_detailed(
        log_object=log_object,
        log_collection=log_collection,
        client=client,
        style=style,
        padding=padding,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    log_object: str,
    log_collection: str,
    *,
    client: Client,
    style: Union[Unset, None, str] = "plain",
    padding: Union[Unset, None, bool] = False,
    fields: Union[Unset, None, str] = "",
) -> Response[Union[HTTPValidationError, str]]:
    """
        GET all the events comprising this log object collection as
        a CSV formatted string


     Description
    -----------
    GET all the events in the collection `logCollection` of the object
    `logObject` as a CSV formatted string.

    By passing a URL query as `style=fancy` a _fancy_ CSV payload is
    returned. Passing a comma-separated string of `fields=<strlist>`
    will only return the `strlist` tokens in the CSV.

    Args:
        log_object (str):
        log_collection (str):
        style (Union[Unset, None, str]):  Default: 'plain'.
        padding (Union[Unset, None, bool]):
        fields (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, str]]
    """

    kwargs = _get_kwargs(
        log_object=log_object,
        log_collection=log_collection,
        client=client,
        style=style,
        padding=padding,
        fields=fields,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    log_object: str,
    log_collection: str,
    *,
    client: Client,
    style: Union[Unset, None, str] = "plain",
    padding: Union[Unset, None, bool] = False,
    fields: Union[Unset, None, str] = "",
) -> Optional[Union[HTTPValidationError, str]]:
    """
        GET all the events comprising this log object collection as
        a CSV formatted string


     Description
    -----------
    GET all the events in the collection `logCollection` of the object
    `logObject` as a CSV formatted string.

    By passing a URL query as `style=fancy` a _fancy_ CSV payload is
    returned. Passing a comma-separated string of `fields=<strlist>`
    will only return the `strlist` tokens in the CSV.

    Args:
        log_object (str):
        log_collection (str):
        style (Union[Unset, None, str]):  Default: 'plain'.
        padding (Union[Unset, None, bool]):
        fields (Union[Unset, None, str]):  Default: ''.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, str]]
    """

    return (
        await asyncio_detailed(
            log_object=log_object,
            log_collection=log_collection,
            client=client,
            style=style,
            padding=padding,
            fields=fields,
        )
    ).parsed



""" Contains all the data models used in inputs/outputs """

from .about_model import AboutModel
from .echo_model import EchoModel
from .hello_model import HelloModel
from .http_validation_error import HTTPValidationError
from .log_core import LogCore
from .log_delete import LogDelete
from .log_event_get_for_object_collection_api_v1_log_log_object_log_collection_log_event_get_response_logevent_getforobjectcollection_api_v1_log_logobject_logcollection_logevent_get import (
    LogEventGetForObjectCollectionApiV1LogLogObjectLogCollectionLogEventGetResponseLogeventGetforobjectcollectionApiV1LogLogobjectLogcollectionLogeventGet,
)
from .log_get_stats_for_object_api_v1_log_log_object_stats_get_response_log_getstatsforobject_api_v1_log_logobject_stats_get import (
    LogGetStatsForObjectApiV1LogLogObjectStatsGetResponseLogGetstatsforobjectApiV1LogLogobjectStatsGet,
)
from .log_get_stats_for_object_collection_api_v1_log_log_object_log_collection_stats_get_response_log_getstatsforobjectcollection_api_v1_log_logobject_logcollection_stats_get import (
    LogGetStatsForObjectCollectionApiV1LogLogObjectLogCollectionStatsGetResponseLogGetstatsforobjectcollectionApiV1LogLogobjectLogcollectionStatsGet,
)
from .log_init import LogInit
from .log_process_stats_for_object_api_v1_log_log_object_stats_process_get_response_log_processstatsforobject_api_v1_log_logobject_stats_process_get import (
    LogProcessStatsForObjectApiV1LogLogObjectStatsProcessGetResponseLogProcessstatsforobjectApiV1LogLogobjectStatsProcessGet,
)
from .log_response import LogResponse
from .log_response_log import LogResponseLog
from .log_simple import LogSimple
from .log_structured import LogStructured
from .sys_info_model import SysInfoModel
from .time import Time
from .validation_error import ValidationError

__all__ = (
    "AboutModel",
    "EchoModel",
    "HelloModel",
    "HTTPValidationError",
    "LogCore",
    "LogDelete",
    "LogEventGetForObjectCollectionApiV1LogLogObjectLogCollectionLogEventGetResponseLogeventGetforobjectcollectionApiV1LogLogobjectLogcollectionLogeventGet",
    "LogGetStatsForObjectApiV1LogLogObjectStatsGetResponseLogGetstatsforobjectApiV1LogLogobjectStatsGet",
    "LogGetStatsForObjectCollectionApiV1LogLogObjectLogCollectionStatsGetResponseLogGetstatsforobjectcollectionApiV1LogLogobjectLogcollectionStatsGet",
    "LogInit",
    "LogProcessStatsForObjectApiV1LogLogObjectStatsProcessGetResponseLogProcessstatsforobjectApiV1LogLogobjectStatsProcessGet",
    "LogResponse",
    "LogResponseLog",
    "LogSimple",
    "LogStructured",
    "SysInfoModel",
    "Time",
    "ValidationError",
)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="AboutModel")


@attr.s(auto_attribs=True)
class AboutModel:
    """
    Attributes:
        name (Union[Unset, str]):  Default: 'pfdcm_hello'.
        about (Union[Unset, str]):  Default: '`pftel` is a simple fastAPI telemetry logger. Clients POST a text payload
            to an API endpoint, which `pftel` will simply log to a file, in a variety of possible formats.\n\nAPI
            documentation is available at :22223/docs\n'.
        version (Union[Unset, str]):  Default: '1.0.0'.
    """

    name: Union[Unset, str] = "pfdcm_hello"
    about: Union[
        Unset, str
    ] = "`pftel` is a simple fastAPI telemetry logger. Clients POST a text payload to an API endpoint, which `pftel` will simply log to a file, in a variety of possible formats.\n\nAPI documentation is available at :22223/docs\n"
    version: Union[Unset, str] = "1.0.0"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        about = self.about
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if about is not UNSET:
            field_dict["about"] = about
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        about = d.pop("about", UNSET)

        version = d.pop("version", UNSET)

        about_model = cls(
            name=name,
            about=about,
            version=version,
        )

        about_model.additional_properties = d
        return about_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.http_validation_error import HTTPValidationError
from ...models.log_response import LogResponse
from ...models.log_simple import LogSimple
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    json_body: LogSimple,
    log_object: Union[Unset, None, str] = "default",
    log_collection: Union[Unset, None, str] = "slog",
    log_event: Union[Unset, None, str] = "log",
) -> Dict[str, Any]:
    url = "{}/api/v1/slog/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["logObject"] = log_object

    params["logCollection"] = log_collection

    params["logEvent"] = log_event

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[HTTPValidationError, LogResponse]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = LogResponse.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[HTTPValidationError, LogResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: LogSimple,
    log_object: Union[Unset, None, str] = "default",
    log_collection: Union[Unset, None, str] = "slog",
    log_event: Union[Unset, None, str] = "log",
) -> Response[Union[HTTPValidationError, LogResponse]]:
    """
        Use this API route to POST a simple log payload to the
        logger.


     Description
    -----------

    Use this API entry point to simply record some log string.
    `slog` entries are by default logged to `default/slog/<count>-log`
    but this can be overriden with appropriate query parameters.

    ```
    {
        log  : str   = \"\"
    }
    ```

    Internally, they are mapped to a complete *telemetry* model for
    consistent processing.

    Args:
        log_object (Union[Unset, None, str]):  Default: 'default'.
        log_collection (Union[Unset, None, str]):  Default: 'slog'.
        log_event (Union[Unset, None, str]):  Default: 'log'.
        json_body (LogSimple): The simplest log model POST

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        log_object=log_object,
        log_collection=log_collection,
        log_event=log_event,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: LogSimple,
    log_object: Union[Unset, None, str] = "default",
    log_collection: Union[Unset, None, str] = "slog",
    log_event: Union[Unset, None, str] = "log",
) -> Optional[Union[HTTPValidationError, LogResponse]]:
    """
        Use this API route to POST a simple log payload to the
        logger.


     Description
    -----------

    Use this API entry point to simply record some log string.
    `slog` entries are by default logged to `default/slog/<count>-log`
    but this can be overriden with appropriate query parameters.

    ```
    {
        log  : str   = \"\"
    }
    ```

    Internally, they are mapped to a complete *telemetry* model for
    consistent processing.

    Args:
        log_object (Union[Unset, None, str]):  Default: 'default'.
        log_collection (Union[Unset, None, str]):  Default: 'slog'.
        log_event (Union[Unset, None, str]):  Default: 'log'.
        json_body (LogSimple): The simplest log model POST

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogResponse]]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        log_object=log_object,
        log_collection=log_collection,
        log_event=log_event,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: LogSimple,
    log_object: Union[Unset, None, str] = "default",
    log_collection: Union[Unset, None, str] = "slog",
    log_event: Union[Unset, None, str] = "log",
) -> Response[Union[HTTPValidationError, LogResponse]]:
    """
        Use this API route to POST a simple log payload to the
        logger.


     Description
    -----------

    Use this API entry point to simply record some log string.
    `slog` entries are by default logged to `default/slog/<count>-log`
    but this can be overriden with appropriate query parameters.

    ```
    {
        log  : str   = \"\"
    }
    ```

    Internally, they are mapped to a complete *telemetry* model for
    consistent processing.

    Args:
        log_object (Union[Unset, None, str]):  Default: 'default'.
        log_collection (Union[Unset, None, str]):  Default: 'slog'.
        log_event (Union[Unset, None, str]):  Default: 'log'.
        json_body (LogSimple): The simplest log model POST

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        log_object=log_object,
        log_collection=log_collection,
        log_event=log_event,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: LogSimple,
    log_object: Union[Unset, None, str] = "default",
    log_collection: Union[Unset, None, str] = "slog",
    log_event: Union[Unset, None, str] = "log",
) -> Optional[Union[HTTPValidationError, LogResponse]]:
    """
        Use this API route to POST a simple log payload to the
        logger.


     Description
    -----------

    Use this API entry point to simply record some log string.
    `slog` entries are by default logged to `default/slog/<count>-log`
    but this can be overriden with appropriate query parameters.

    ```
    {
        log  : str   = \"\"
    }
    ```

    Internally, they are mapped to a complete *telemetry* model for
    consistent processing.

    Args:
        log_object (Union[Unset, None, str]):  Default: 'default'.
        log_collection (Union[Unset, None, str]):  Default: 'slog'.
        log_event (Union[Unset, None, str]):  Default: 'log'.
        json_body (LogSimple): The simplest log model POST

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, LogResponse]]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            log_object=log_object,
            log_collection=log_collection,
            log_event=log_event,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LogStructured")


@attr.s(auto_attribs=True)
class LogStructured:
    """A simple structured log model

    Attributes:
        log_object (Union[Unset, str]):  Default: 'default'.
        log_collection (Union[Unset, str]):  Default: ''.
        log_event (Union[Unset, str]):  Default: ''.
        app_name (Union[Unset, str]):  Default: ''.
        exec_time (Union[Unset, float]):
        request_host (Union[Unset, str]):  Default: ''.
        request_port (Union[Unset, str]):  Default: ''.
        request_user_agent (Union[Unset, str]):  Default: ''.
        payload (Union[Unset, str]):  Default: ''.
    """

    log_object: Union[Unset, str] = "default"
    log_collection: Union[Unset, str] = ""
    log_event: Union[Unset, str] = ""
    app_name: Union[Unset, str] = ""
    exec_time: Union[Unset, float] = 0.0
    request_host: Union[Unset, str] = ""
    request_port: Union[Unset, str] = ""
    request_user_agent: Union[Unset, str] = ""
    payload: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        log_object = self.log_object
        log_collection = self.log_collection
        log_event = self.log_event
        app_name = self.app_name
        exec_time = self.exec_time
        request_host = self.request_host
        request_port = self.request_port
        request_user_agent = self.request_user_agent
        payload = self.payload

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if log_object is not UNSET:
            field_dict["logObject"] = log_object
        if log_collection is not UNSET:
            field_dict["logCollection"] = log_collection
        if log_event is not UNSET:
            field_dict["logEvent"] = log_event
        if app_name is not UNSET:
            field_dict["appName"] = app_name
        if exec_time is not UNSET:
            field_dict["execTime"] = exec_time
        if request_host is not UNSET:
            field_dict["requestHost"] = request_host
        if request_port is not UNSET:
            field_dict["requestPort"] = request_port
        if request_user_agent is not UNSET:
            field_dict["requestUserAgent"] = request_user_agent
        if payload is not UNSET:
            field_dict["payload"] = payload

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        log_object = d.pop("logObject", UNSET)

        log_collection = d.pop("logCollection", UNSET)

        log_event = d.pop("logEvent", UNSET)

        app_name = d.pop("appName", UNSET)

        exec_time = d.pop("execTime", UNSET)

        request_host = d.pop("requestHost", UNSET)

        request_port = d.pop("requestPort", UNSET)

        request_user_agent = d.pop("requestUserAgent", UNSET)

        payload = d.pop("payload", UNSET)

        log_structured = cls(
            log_object=log_object,
            log_collection=log_collection,
            log_event=log_event,
            app_name=app_name,
            exec_time=exec_time,
            request_host=request_host,
            request_port=request_port,
            request_user_agent=request_user_agent,
            payload=payload,
        )

        log_structured.additional_properties = d
        return log_structured

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.log_response_log import LogResponseLog


T = TypeVar("T", bound="LogResponse")


@attr.s(auto_attribs=True)
class LogResponse:
    """A model returned a log is POSTed

    Attributes:
        log (LogResponseLog):
        status (bool):
        timestamp (str):
        message (str):
    """

    log: "LogResponseLog"
    status: bool
    timestamp: str
    message: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        log = self.log.to_dict()

        status = self.status
        timestamp = self.timestamp
        message = self.message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "log": log,
                "status": status,
                "timestamp": timestamp,
                "message": message,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.log_response_log import LogResponseLog

        d = src_dict.copy()
        log = LogResponseLog.from_dict(d.pop("log"))

        status = d.pop("status")

        timestamp = d.pop("timestamp")

        message = d.pop("message")

        log_response = cls(
            log=log,
            status=status,
            timestamp=timestamp,
            message=message,
        )

        log_response.additional_properties = d
        return log_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
